function [h, t_axis] = ifft1(H, freq)
% IFFT1 Calculates a 1-sided ifft with the same scaling as the standard ifft
% 
% DESCRIPTION:
% Single-sided inverse fft transform, f = 0 ... fs/2
% number of input samples must be odd
% size(H) = M+1  --> size(h) = 2M    f = (0:M)/(2*M)*fs
% 
% HISTORY:
% Version 0.1 1999-08-18 Created by Pal Frenger KI/ERA/T/UR
% 
% Copyright (c) 1999 by Ericsson Radio AB



%--- Check the number of frequency samples
if mod(length(H),2) == 0             % Even number of tones (Only an odd...
                                         %...number is acepted to ifft).
    H2 = H(1:length(H)-1);
    freq_ifft(:,1) = freq(1:length(freq)-1);
else
    H2 = H;
    freq_ifft(:,1) = freq;
end


%--- Calculation
M = max(size(H2)); 
N = 2*(M - 1);  % N = number of time samples, 96-09
if (2*fix(M/2)) == M
  fprintf('Input to IFFT1-routine does not have an odd number of points');
  return;
end

H1 = H2; 
H1(M+1:2*M-2) = conj(H1(M-1:-1:2));
h = real(ifft(H1,N));


Ts = (2*freq_ifft(length(freq_ifft)))^-1;
t_axis = 0:Ts:(N-1)*Ts;
t_axis = t_axis';

