function Zin = input_imp(ABCD, Zload)

%==========================================================================
%                    INPUT IMPEDANCE FROM ABCD MATRIX
%                                                                         
% Description:                                                            
%   This function calculates the input impedance of an arbitrary 
%   subscriber line from its ABCD matrix.
%==========================================================================
% Input parameter(s):
%   ABCD           Overall downstream (CO->CPE) or upstream (CPE->CO) ABCD 
%                  matrix of the line. It has the following 
%                  dimensions: no. of frequency samples x 4.
%   Zload          Real or complex value describing the impedance of the 
%                  load attached to the remote end of the line.      [Ohms]
%==========================================================================
% Output parameter(s):
%   Zin            Column-vector describing the input impedance of the 
%                  subscriber line.                                  [Ohms]
%==========================================================================

%==========================================================================
% Author(s):
%   Roberto Menezes (RoMe / menegues@ufpa.br / UFPA)
%   Licinius Alcantara (LiAl / linicius@ufpa.br / UFPA)
%==========================================================================
% Change history (yyyy-mm-dd):
%   2005-03-09    (LiAl/RoMe)   Created.
%==========================================================================
% Version: ??
%==========================================================================
% Known bugs (-) or limitations (*):                                      
%   None detected yet.
%==========================================================================
% Copyright (c) 2005 UFPA, Federal University of Para, Brazil.
%==========================================================================


%=== Decomposition of "ABCD" matrix:
    
A = ABCD(:,1);
B = ABCD(:,2);
C = ABCD(:,3);
D = ABCD(:,4);


%=== Input impedance calculation:

if Zload == 0
    num = A.*Zload + B;
    den = C.*Zload + D;
else
    num = A  +  B./Zload;
    den = C  +  D./Zload;
end

Zin = num./den;



                          % END OF CODE %                        
                          