%% ==== BASIC PARAMETERS

close all
clc

% Frequency axis without zero:
frequencyAxis = (4312.5:4312.5:11997375)'; 

% Line Model: 'VUB0', 'BT1', 'MAR2'.
lineModel = 'MAR2'; 

% Parameters needed to generate the frequency response
reference = 'source';
Zl = 100; % Load Impedance.


%% Topology definition to be simulated:

% Type of each section in the order that present themselves:
    % 'serial' = serial
    % 'bridge-tap' = derivation
topology.type = {'serial','serial','bridge-tap','serial','bridge-tap','serial'};

%Cable type represented by the gauge. The values ??can be:
    % 0.32, 0.40, 0.50, 0.63, 0.65, 0.90. (in mm)
topology.gauge = [0.4 0.5 0.5 0.5 0.5 0.5];
        
% Section length in Km.
topology.length = [0.500 0.300 0.400 0.350 0.200 0.850];
        
        
%% ABCD matrix of topology:

[ABCD, ~] = ABCD_custom(frequencyAxis, topology, lineModel);


%% ==== Frequency response and "Impulse response"

% Frequency response:
Hf = t_function(ABCD, reference, Zl);

% Resposta ao impulso:
[newTrF, newF] = pre_processing(Hf, frequencyAxis); % windowing and etc.
[h, timeAxish] = ifft1(newTrF, newF); % h = impulse response


%% ==== Input Impedance e Response to the TDR

%Input impedance in frequency domain with end open
Zl = 1e27;
ZinO = input_imp(ABCD, Zl); 

%Input impedance in frequency domain with end short
Zl = 0;
ZinS = input_imp(ABCD, Zl); 

% Response to the TDR
Reflectogram = pp_generate_TDR(ZinO, frequencyAxis);
                                         %It uses the voltage divider and
                                         %results in a signal in frequency
                                         
[Reflectogram, newF] = pre_processing(Reflectogram, frequencyAxis);
                                         % windowing and etc.
[r, timeAxisr] = ifft1(Reflectogram, newF); % r = response to the TDR.

%It can use the "s_parameters" function to get the scattering parameters 

% timeAxisr = timeAxish


%% ==== Plots in time domain.

figure
plot(timeAxish, h, '-k')
xlabel('Tempo (s)')
ylabel('Amplitude (V)')

figure
plot(timeAxisr, r, '-k')
xlabel('Tempo (s)')
ylabel('Amplitude (V)')