function [newSignal, newFrequencyAxis] = pre_processing...
    (signal, frequencyAxis, DCLevel, window)

%% ==== "FORWARD ZERO-PADDING": INCLUDING DC COMPONENT

if nargin < 4
    DCLevel = 'extrapolated';
end

switch DCLevel
    case 'zero'
        % Frequency Response => the bin in f = 0hz is equal to zero
        newSignal = [0; signal];
    case 'extrapolated'
        % Extrapolate the DC level:
        DCLevel = interp1(frequencyAxis, signal, 0, 'spline', 'extrap');
        newSignal = [DCLevel; signal];
    otherwise
        display('Option for DC level is invalid!')
        display('The default method (extrapolation) will be used.')
        % Extrapolate the DC level:
        DCLevel = interp1(frequencyAxis, signal, 0, 'spline', 'extrap');
        newSignal = [DCLevel; signal];
end

newFrequencyAxis = [0; frequencyAxis];
% newSignal = signal;
% newFrequencyAxis = frequencyAxis;

%% ==== HERMITIAN SYMMETRY
% Talvez a simetria hermitiana deva ser aplicada somente depois do
% processamento. Isso certamente mudaria bastante o resultado.

newSignal = [conj(newSignal(end - 1:-1:2)); newSignal];
newFrequencyAxis = [-newFrequencyAxis(end - 1:-1:2); newFrequencyAxis];
nTones = length(newFrequencyAxis);


%% ==== WINDOWING 

if nargin < 3
    % Increasing beta widens the main lobe and decreases the amplitude of
    % the sidelobes (i.e., increases the attenuation).
    beta = 9;
    window = kaiser(nTones, beta);
end

newSignal = newSignal.*window;


%% ==== REMOVE THE FIRST AND THE LAST FREQUENCY COMPONENTS

% === Return just the positive frequencies with zero

lPositiveFreq = newFrequencyAxis >= 0;
indexPos = find(lPositiveFreq);

newFrequencyAxis = newFrequencyAxis(indexPos);
newSignal = newSignal(indexPos);

% In order to have a real inverse Fourier Transform:
% => Remove phase from DC frequency
% => Remove phase from Nyquist frequency
newSignal(1) = abs(newSignal(1)); 
newSignal(end) = abs(newSignal(end));