function TrF = t_function(ABCD, reference, Zload)


%==========================================================================
%                  TRANSFER FUNCTION FROM ABCD MATRIX
%                                                                         
% Description:                                                            
%   This function calculates the transfer function (forward or backward) 
%   of an arbitrary subscriber line from its ABCD matrix.
%==========================================================================
% Input parameter(s):
%   ABCD           Overall downstream (CO->CPE) or upstream (CPE->CO) ABCD 
%                  matrix of the line. It has the following 
%                  dimensions: no. of frequency samples x 4.
%   reference      String defining the reference for transfer function 
%                  calculation: "input" --> (V2/V1) and 
%                  "source " --> (V2/Vs).
%   Zload          Real or complex value describing the impedance of the 
%                  load attached to the remote end of the line.      [Ohms]
%==========================================================================
% Output parameter(s):
%   TrF            Column-vector describing the transfer function of the 
%                  subscriber line.
%==========================================================================

%==========================================================================
% Author(s):
%   Roberto Menezes (RoMe / menegues@ufpa.br / UFPA)
%   Licinius Alcantara (LiAl / linicius@ufpa.br / UFPA)
%==========================================================================
% Change history (yyyy-mm-dd):
%   2005-03-09    (LiAl/RoMe)   Created.
%==========================================================================
% Version: ??
%==========================================================================
% Known bugs (-) or limitations (*):                                      
%   None detected yet.
%==========================================================================
% Copyright (c) 2005 UFPA, Federal University of Para, Brazil.
%==========================================================================


%=== Source impedance value for transfer function calculation:                  

if strcmp(reference, 'source')
    Zsource = Zload;    
elseif strcmp(reference, 'input')
    Zsource = 0;    
else
    error('Wrongly typed! --> "Reference" (settings.m)');    
end


%=== Decomposition of ABCD matrix: 
    
A = ABCD(:,1);
B = ABCD(:,2);
C = ABCD(:,3);
D = ABCD(:,4);


%=== Transfer function calculation: 

if Zload == 0
    num = Zload;
    den = A.*Zload + B + C.*Zsource*Zload + D.*Zsource;
else
    num = 1;
    den = A  +  B./Zload  +  C.*Zsource  +  (D.*Zsource)./Zload;    
end

TrF = num./den;
    
    

                        % END OF CODE %  
                        