function [ABCD,  varargout] = ABCD_custom(freq, makeup, cableModel, varargin)


%==========================================================================
%                    ABCD MATRIX FROM THE LINE TOPOLOGY
%                                                                         
% Description:
%   This function calculates the forward and backward overall ABCD matrix 
%   for a line under test (LUT) based on its topology.
%==========================================================================
% Input parameter(s):
%   freq           Row-vector containing the sample frequencies related  
%                  to the measured or simulated data.               [Hertz]
%   makeup         Structure describing the topology of the LUT.
%   cableModel     Cable model to be used. 
%==========================================================================
% Output parameter(s):
%   downABCD       Forward ABCD matrix of LUT. Matrix with dimension 
%                  (no. of frequency samples x 4).
%   upABCD         Backward ABCD matrix of LUT. Matrix with dimension 
%                  (no. of frequency samples x 4).
%==========================================================================

%==========================================================================
% Author(s):
%   Roberto Menezes (RoMe / menegues@ufpa.br / UFPA)
%==========================================================================
% Change history (yyyy-mm-dd):
%   2005-08-14    (RoMe)        Created.
%   2009-05-21    (RoMe)        Cleaning up and rename of variables based 
%                               on predefined coding conventions.
%==========================================================================
% Version: ??
%==========================================================================
% Known bugs (-) or limitations (*):                                      
%   None detected yet.
%==========================================================================
% Copyright (c) 2005 UFPA, Federal University of Para, Brazil.
%==========================================================================


%=== Secundary parameters from the selected cable model: 

if strcmp(cableModel,'VUB0')
    [Z0, gamma] = VUB0_model(makeup.gauge, freq);
           
elseif strcmp(cableModel,'BT1')        
    [Z0, gamma] = BT1_model(makeup.gauge, freq);
      
elseif strcmp(cableModel, 'MAR2')    
    [Z0, gamma] = MAR2_model(makeup.gauge, freq);

elseif strcmp(cableModel, 'KHM')
    [Z0, gamma] = KHM_model(makeup.cable, freq);
    
else        
    error('unexpected value for the variable "cableModel"');

end


%=== ABCD matrix(ces): 

gammaL = gamma*diag(makeup.length);
[ABCD, temp] = ABCD_matrix(makeup.type, gammaL, Z0, varargin);
varargout = {temp};



                         % END OF CODE %
