% rate = calc_rates(H, f, Gfast) calcula a taxa para o padro G.fast,onde a varivel Gfast pode ser um dos seguintes strings:
% - 'G.fast100_0': De 0 MHz  106 MHz;
% - 'G.fast200_0': De 0 MHz  212 MHz;
% - 'G.fast100_1': De 2.2 MHz  106 MHz;
% - 'G.fast200_1': De 2.2 MHz  212 MHz;
% - 'G.fast100_2': De 17 MHz  106 MHz;
% - 'G.fast200_2': De 17 MHz  212 MHz;
% - 'G.fast100_3': De 30 MHz  106 MHz;
% - 'G.fast200_3': De 30 MHz  212 MHz;
% 
% calc_rates(H, f, txPSD_dBm) calcula a taxa torica de Shannon considerando apenas rudo de fundo, onde a varivel txPSD_dBm  a potncia injetada na linha em dBm.
% 
% calc_rates(H, f, txPSD_dBm, noisePSD_dBm) calcula a taxa torica de Shannon considerando um ruido definido por noisePSD_dBm em dBm.
% 
% rate = calc_rates2(H, f, txPSD_dBm, noisePSD_dBm, snr_gap_tot_dB, min_max_bitload, oh_frame) calcula a taxa definindo-se tudo. Onde:
% - snr_gap_tot_dB = [codingGain_dBm  snr_margin_dBm  snr_gap_dBm]
% - min_max_bitload = [min_bitload max_bitload]
function rate = calc_rates(H, f, varargin)

if (nargin == 3)
    if  ischar(varargin{1}) % G.fast
        txPSD_dBm = -76;
        noisePSD_dBm = -140;

        codingGain_dBm = 5; 
        snr_margin_dBm = 6; 
        snr_gap_dBm = 9.8;

        min_bits_per_tone = 0.5;
        max_bits_per_tone = 12;

        oh_frame = 0.12;

        switch varargin{1}
            case 'G.fast100_0'
                freq = (51.75e3*(1:2048)).';
            case 'G.fast200_0'
                freq = (51.75e3*(1:4096)).';
            case 'G.fast100_1'
                freq = (51.75e3*(43:2048)).';
            case 'G.fast200_1'
                freq = (51.75e3*(43:4096)).';
            case 'G.fast100_2'
                freq = (51.75e3*(330:2048)).';
            case 'G.fast200_2'
                freq = (51.75e3*(330:4096)).';
            case 'G.fast100_3'
                freq = (51.75e3*(600:2048)).';
            case 'G.fast200_3'
                freq = (51.75e3*(600:4096)).';
            otherwise
                error('myApp:argChk', 'Unknown input parameter.')
        end
        H = interp1(f, H, freq);

    else % S rudo de fundo
        txPSD_dBm = varargin{1};
        noisePSD_dBm = -140;

        codingGain_dBm = 0; 
        snr_margin_dBm = 0; 
        snr_gap_dBm = 0;

        min_bits_per_tone = 0;
        max_bits_per_tone = 100;
        
        oh_frame = 0;
    end
end

if (nargin == 4)
    freq = f;
    
    txPSD_dBm = varargin{1};
    noisePSD_dBm = varargin{2};
    
    codingGain_dBm = 0; 
    snr_margin_dBm = 0; 
    snr_gap_dBm    = 0;

    min_bits_per_tone = 0;
    max_bits_per_tone = 100;

    oh_frame = 0; 
end

if (nargin == 7)
    freq = f;
    
    txPSD_dBm = varargin{1};
    noisePSD_dBm = varargin{2};
    
    codingGain_dBm = varargin{3}(1);
    snr_margin_dBm = varargin{3}(2);
    snr_gap_dBm    = varargin{3}(3);

    min_bits_per_tone = varargin{4}(1);
    max_bits_per_tone = varargin{4}(2);
    
    oh_frame = varargin{5}(1);
end

C = log2(1 + abs(H(:)).^2 * 10^(0.1*(txPSD_dBm + codingGain_dBm - noisePSD_dBm - snr_gap_dBm - snr_margin_dBm)));

bitLoad_TH = (C >= min_bits_per_tone).*min([max_bits_per_tone*ones(length(H), 1) C],[],2);

diff_f = diff(freq(:));
rate = (1-oh_frame)*sum(bitLoad_TH .* [diff_f(1) ; (diff_f(1:end-1)+diff_f(2:end))/2 ; diff_f(end)]);