function h=ak_getImpulseResponse(H)
% function h=ak_getImpulseResponse(H)
% Input: H => complex-valued frequency response
% Output: h => real-valued impulse response
% It is assumed that H is provided only for non-negative frequencies,
% i.e., from k=0 (DC) to a value not larger than Nyquist frequency.
% Examples of usage:
%  N=4;X=fft(1:N);h=ak_getImpulseResponse(X(1:N/2+1)) %N even
%  N=5;X=fft(1:N);h=ak_getImpulseResponse(X(1:(N-1)/2+1)) %N od
H = H(:); %make it a column vector
if ~isreal(H(1))
    error(['DC value must be real, but H(1)=' num2str(H(1))]);
end
if isreal(H(end)) %if real, assume H(end) is the Nyquist frequency 
    %and compose a DFT of N-points with N an even number:
    H = [H; conj(H(end-1:-1:2))]; %add Hermitian symmetry
else %Compose a DFT of N-points with N an odd number:
    H = [H; conj(H(end:-1:2))]; %add Hermitian symmetry
end
h = ifft(H); %find impulse response