function Hf=getFrequencyResponseFromABCD(ABCD,Zsource,Zload)
%function Hf=getFrequencyResponseFromABCD(ABCD,Zsource,Zload)
% TRANSFER FUNCTION FROM ABCD MATRIX. Description:                                                            
%   This function calculates the transfer function (forward or backward) 
%   of an arbitrary subscriber line from its ABCD matrix.
%==========================================================================
% Input parameter(s):
%   ABCD           Overall downstream (CO->CPE) or upstream (CPE->CO) ABCD 
%                  matrix of the line. It has the following 
%                  dimension: no. of frequency samples x 4.
%   Zsource        Source impedance in Ohms. Use Zsource=0 if the reference for
%                  transfer function calculation is the "input" --> (V2/V1) or 
%                  Zsource=Zload if it is the "source " --> (V2/Vs).
%   Zload          Real or complex value describing the impedance of the 
%                  load attached to the remote end of the line in Ohms
%==========================================================================
% Output parameter(s):
%   Hf              Column-vector describing the frequency response of the 
%                    circuit.
%==========================================================================

%==========================================================================
% Author(s):
%   Roberto Menezes (RoMe / menegues@ufpa.br / UFPA)
%   Licinius Alcantara (LiAl / linicius@ufpa.br / UFPA)
%==========================================================================
% Change history (yyyy-mm-dd):
%   2005-03-09    (LiAl/RoMe)   Created.
%   2015-02-18    (Aldebaro) Changed input parameter and editorial changes.
%==========================================================================
% Copyright (c) 2005 UFPA, Federal University of Para, Brazil.
%==========================================================================

%% Decomposition of ABCD matrix: 
A = ABCD(:,1);
B = ABCD(:,2);
C = ABCD(:,3);
D = ABCD(:,4);
%% Frequency response calculation: 
if Zload == 0
    num = Zload;
    den = A.*Zload + B + C.*Zsource*Zload + D.*Zsource;
else
    num = 1;
    den = A  +  B./Zload  +  C.*Zsource  +  (D.*Zsource)./Zload;    
end
Hf = num./den;
