%% Initialize:
clear all, close all
frequencyAxis = transpose(0:4312.5:11997375); %use ADSL frequencies
frequencyAxis(1)=eps; %avoid numerical error for a zero frequency
% Choose line Model: 'VUB0', 'BT1', 'MAR2'.
lineModel = 'BT1';
% Parameters needed to generate the frequency response
Zl = 100; % Load impedance in Ohms
Zs = Zl;  %Source impedance in Ohms
%% Topology definition to be simulated:
% Type of each section in the order that present themselves:
% 'serial' = serial or 'bridge-tap' = derivation
if 1
    topology.type = {'serial','serial','bridge-tap','serial',...
        'bridge-tap','serial'};
    %Cable type represented by the gauge. The values can be:
    % 0.32, 0.40, 0.50, 0.63, 0.65, 0.90. (in mm)
    topology.gauge = [0.4 0.5 0.5 0.5 0.5 0.5];
    % Section length in Km.
    topology.length = [0.500 0.300 0.400 0.350 0.200 0.850];
else
    topology.type = {'serial','bridge-tap','serial'};
    topology.gauge = [0.4 0.9 0.9];
    topology.length = [2 0.05 0.05];
end
%% Topology ABCD matrix
[ABCD, temp] = ABCD_custom(frequencyAxis, topology, lineModel);
Zin = getInputImpedanceFromABCD(ABCD, Zl); %not being used here
%% Frequency response and impulse response:
Hf = getFrequencyResponseFromABCD(ABCD, Zs, Zl); %only positive freqs
frequencyAxis(1) = 0; %substitute eps by 0
Hf(1) = real(Hf(1)); %eliminate any imaginary value from DC
h=ak_getImpulseResponse(Hf); % Impulse response
t=(0:length(h)-1)*(1/(frequencyAxis(2)-frequencyAxis(1))); %time axis
%% Plots in frequency and time domains:
subplot(211); plot(t,h),xlabel('Time (s)'),ylabel('Impulse response')
subplot(212); plot(frequencyAxis,20*log10(abs(Hf)))
xlabel('Frequency (Hz)'), ylabel('|H(f)| (dB)')