function [ tx_data_matrix ] = interleave(tx_enc0,tx_enc1)
%
% interleave:  
%           This function performs interleaving of two information
%           blocks, each containing 456 bits of information. Output 
%           is an matrix with 4 rows, each containing 114 bits of 
%           information for inclusion in an GSM burst. 
%
% SYNTAX:   [ tx_data_matrix ] = interleave(tx_enc0,tx_enc1)
%
% INPUT:    tx_enc0:
%                 The first block in an interleaving pass.
%           tx_enc1:
%                 The second block in an interleaving pass.
%
% OUTPUT:   tx_data_matrix: 
%                 A matrix containing 114 bits of data in each row,
%                 ready to be split into two and passed to burst_g.m
%
% WARNINGS: Not all 2 x 456 bits are represented in the output, this is
%           exactely as specified in the recommadations.
%
% TEST(S):  interleave -> deinterleave = 0 Errors.
%
% AUTHOR:   Jan H. Mikkelsen / Arne Norre Ekstrm
% EMAIL:    hmi@kom.auc.dk / aneks@kom.auc.dk
%
% $Id: interleave.m,v 1.4 1997/11/20 11:10:42 aneks Exp $
tx_data_matrix(1,1)=tx_enc1(1);
tx_data_matrix(1,2)=tx_enc0(229);
tx_data_matrix(1,3)=tx_enc1(65);
tx_data_matrix(1,4)=tx_enc0(293);
tx_data_matrix(1,5)=tx_enc1(129);
tx_data_matrix(1,6)=tx_enc0(357);
tx_data_matrix(1,7)=tx_enc1(193);
tx_data_matrix(1,8)=tx_enc0(421);
tx_data_matrix(1,9)=tx_enc1(257);
tx_data_matrix(1,10)=tx_enc0(29);
tx_data_matrix(1,11)=tx_enc1(321);
tx_data_matrix(1,12)=tx_enc0(93);
tx_data_matrix(1,13)=tx_enc1(385);
tx_data_matrix(1,14)=tx_enc0(157);
tx_data_matrix(1,15)=tx_enc1(449);
tx_data_matrix(1,16)=tx_enc0(221);
tx_data_matrix(1,17)=tx_enc1(57);
tx_data_matrix(1,18)=tx_enc0(285);
tx_data_matrix(1,19)=tx_enc1(121);
tx_data_matrix(1,20)=tx_enc0(349);
tx_data_matrix(1,21)=tx_enc1(185);
tx_data_matrix(1,22)=tx_enc0(413);
tx_data_matrix(1,23)=tx_enc1(249);
tx_data_matrix(1,24)=tx_enc0(21);
tx_data_matrix(1,25)=tx_enc1(313);
tx_data_matrix(1,26)=tx_enc0(85);
tx_data_matrix(1,27)=tx_enc1(377);
tx_data_matrix(1,28)=tx_enc0(149);
tx_data_matrix(1,29)=tx_enc1(441);
tx_data_matrix(1,30)=tx_enc0(213);
tx_data_matrix(1,31)=tx_enc1(49);
tx_data_matrix(1,32)=tx_enc0(277);
tx_data_matrix(1,33)=tx_enc1(113);
tx_data_matrix(1,34)=tx_enc0(341);
tx_data_matrix(1,35)=tx_enc1(177);
tx_data_matrix(1,36)=tx_enc0(405);
tx_data_matrix(1,37)=tx_enc1(241);
tx_data_matrix(1,38)=tx_enc0(13);
tx_data_matrix(1,39)=tx_enc1(305);
tx_data_matrix(1,40)=tx_enc0(77);
tx_data_matrix(1,41)=tx_enc1(369);
tx_data_matrix(1,42)=tx_enc0(141);
tx_data_matrix(1,43)=tx_enc1(433);
tx_data_matrix(1,44)=tx_enc0(205);
tx_data_matrix(1,45)=tx_enc1(41);
tx_data_matrix(1,46)=tx_enc0(269);
tx_data_matrix(1,47)=tx_enc1(105);
tx_data_matrix(1,48)=tx_enc0(333);
tx_data_matrix(1,49)=tx_enc1(169);
tx_data_matrix(1,50)=tx_enc0(397);
tx_data_matrix(1,51)=tx_enc1(233);
tx_data_matrix(1,52)=tx_enc0(5);
tx_data_matrix(1,53)=tx_enc1(297);
tx_data_matrix(1,54)=tx_enc0(69);
tx_data_matrix(1,55)=tx_enc1(361);
tx_data_matrix(1,56)=tx_enc0(133);
tx_data_matrix(1,57)=tx_enc1(425);
tx_data_matrix(1,58)=tx_enc0(197);
tx_data_matrix(1,59)=tx_enc1(33);
tx_data_matrix(1,60)=tx_enc0(261);
tx_data_matrix(1,61)=tx_enc1(97);
tx_data_matrix(1,62)=tx_enc0(325);
tx_data_matrix(1,63)=tx_enc1(161);
tx_data_matrix(1,64)=tx_enc0(389);
tx_data_matrix(1,65)=tx_enc1(225);
tx_data_matrix(1,66)=tx_enc0(453);
tx_data_matrix(1,67)=tx_enc1(289);
tx_data_matrix(1,68)=tx_enc0(61);
tx_data_matrix(1,69)=tx_enc1(353);
tx_data_matrix(1,70)=tx_enc0(125);
tx_data_matrix(1,71)=tx_enc1(417);
tx_data_matrix(1,72)=tx_enc0(189);
tx_data_matrix(1,73)=tx_enc1(25);
tx_data_matrix(1,74)=tx_enc0(253);
tx_data_matrix(1,75)=tx_enc1(89);
tx_data_matrix(1,76)=tx_enc0(317);
tx_data_matrix(1,77)=tx_enc1(153);
tx_data_matrix(1,78)=tx_enc0(381);
tx_data_matrix(1,79)=tx_enc1(217);
tx_data_matrix(1,80)=tx_enc0(445);
tx_data_matrix(1,81)=tx_enc1(281);
tx_data_matrix(1,82)=tx_enc0(53);
tx_data_matrix(1,83)=tx_enc1(345);
tx_data_matrix(1,84)=tx_enc0(117);
tx_data_matrix(1,85)=tx_enc1(409);
tx_data_matrix(1,86)=tx_enc0(181);
tx_data_matrix(1,87)=tx_enc1(17);
tx_data_matrix(1,88)=tx_enc0(245);
tx_data_matrix(1,89)=tx_enc1(81);
tx_data_matrix(1,90)=tx_enc0(309);
tx_data_matrix(1,91)=tx_enc1(145);
tx_data_matrix(1,92)=tx_enc0(373);
tx_data_matrix(1,93)=tx_enc1(209);
tx_data_matrix(1,94)=tx_enc0(437);
tx_data_matrix(1,95)=tx_enc1(273);
tx_data_matrix(1,96)=tx_enc0(45);
tx_data_matrix(1,97)=tx_enc1(337);
tx_data_matrix(1,98)=tx_enc0(109);
tx_data_matrix(1,99)=tx_enc1(401);
tx_data_matrix(1,100)=tx_enc0(173);
tx_data_matrix(1,101)=tx_enc1(9);
tx_data_matrix(1,102)=tx_enc0(237);
tx_data_matrix(1,103)=tx_enc1(73);
tx_data_matrix(1,104)=tx_enc0(301);
tx_data_matrix(1,105)=tx_enc1(137);
tx_data_matrix(1,106)=tx_enc0(365);
tx_data_matrix(1,107)=tx_enc1(201);
tx_data_matrix(1,108)=tx_enc0(429);
tx_data_matrix(1,109)=tx_enc1(265);
tx_data_matrix(1,110)=tx_enc0(37);
tx_data_matrix(1,111)=tx_enc1(329);
tx_data_matrix(1,112)=tx_enc0(101);
tx_data_matrix(1,113)=tx_enc1(393);
tx_data_matrix(1,114)=tx_enc0(165);
tx_data_matrix(2,1)=tx_enc1(58);
tx_data_matrix(2,2)=tx_enc0(286);
tx_data_matrix(2,3)=tx_enc1(122);
tx_data_matrix(2,4)=tx_enc0(350);
tx_data_matrix(2,5)=tx_enc1(186);
tx_data_matrix(2,6)=tx_enc0(414);
tx_data_matrix(2,7)=tx_enc1(250);
tx_data_matrix(2,8)=tx_enc0(22);
tx_data_matrix(2,9)=tx_enc1(314);
tx_data_matrix(2,10)=tx_enc0(86);
tx_data_matrix(2,11)=tx_enc1(378);
tx_data_matrix(2,12)=tx_enc0(150);
tx_data_matrix(2,13)=tx_enc1(442);
tx_data_matrix(2,14)=tx_enc0(214);
tx_data_matrix(2,15)=tx_enc1(50);
tx_data_matrix(2,16)=tx_enc0(278);
tx_data_matrix(2,17)=tx_enc1(114);
tx_data_matrix(2,18)=tx_enc0(342);
tx_data_matrix(2,19)=tx_enc1(178);
tx_data_matrix(2,20)=tx_enc0(406);
tx_data_matrix(2,21)=tx_enc1(242);
tx_data_matrix(2,22)=tx_enc0(14);
tx_data_matrix(2,23)=tx_enc1(306);
tx_data_matrix(2,24)=tx_enc0(78);
tx_data_matrix(2,25)=tx_enc1(370);
tx_data_matrix(2,26)=tx_enc0(142);
tx_data_matrix(2,27)=tx_enc1(434);
tx_data_matrix(2,28)=tx_enc0(206);
tx_data_matrix(2,29)=tx_enc1(42);
tx_data_matrix(2,30)=tx_enc0(270);
tx_data_matrix(2,31)=tx_enc1(106);
tx_data_matrix(2,32)=tx_enc0(334);
tx_data_matrix(2,33)=tx_enc1(170);
tx_data_matrix(2,34)=tx_enc0(398);
tx_data_matrix(2,35)=tx_enc1(234);
tx_data_matrix(2,36)=tx_enc0(6);
tx_data_matrix(2,37)=tx_enc1(298);
tx_data_matrix(2,38)=tx_enc0(70);
tx_data_matrix(2,39)=tx_enc1(362);
tx_data_matrix(2,40)=tx_enc0(134);
tx_data_matrix(2,41)=tx_enc1(426);
tx_data_matrix(2,42)=tx_enc0(198);
tx_data_matrix(2,43)=tx_enc1(34);
tx_data_matrix(2,44)=tx_enc0(262);
tx_data_matrix(2,45)=tx_enc1(98);
tx_data_matrix(2,46)=tx_enc0(326);
tx_data_matrix(2,47)=tx_enc1(162);
tx_data_matrix(2,48)=tx_enc0(390);
tx_data_matrix(2,49)=tx_enc1(226);
tx_data_matrix(2,50)=tx_enc0(454);
tx_data_matrix(2,51)=tx_enc1(290);
tx_data_matrix(2,52)=tx_enc0(62);
tx_data_matrix(2,53)=tx_enc1(354);
tx_data_matrix(2,54)=tx_enc0(126);
tx_data_matrix(2,55)=tx_enc1(418);
tx_data_matrix(2,56)=tx_enc0(190);
tx_data_matrix(2,57)=tx_enc1(26);
tx_data_matrix(2,58)=tx_enc0(254);
tx_data_matrix(2,59)=tx_enc1(90);
tx_data_matrix(2,60)=tx_enc0(318);
tx_data_matrix(2,61)=tx_enc1(154);
tx_data_matrix(2,62)=tx_enc0(382);
tx_data_matrix(2,63)=tx_enc1(218);
tx_data_matrix(2,64)=tx_enc0(446);
tx_data_matrix(2,65)=tx_enc1(282);
tx_data_matrix(2,66)=tx_enc0(54);
tx_data_matrix(2,67)=tx_enc1(346);
tx_data_matrix(2,68)=tx_enc0(118);
tx_data_matrix(2,69)=tx_enc1(410);
tx_data_matrix(2,70)=tx_enc0(182);
tx_data_matrix(2,71)=tx_enc1(18);
tx_data_matrix(2,72)=tx_enc0(246);
tx_data_matrix(2,73)=tx_enc1(82);
tx_data_matrix(2,74)=tx_enc0(310);
tx_data_matrix(2,75)=tx_enc1(146);
tx_data_matrix(2,76)=tx_enc0(374);
tx_data_matrix(2,77)=tx_enc1(210);
tx_data_matrix(2,78)=tx_enc0(438);
tx_data_matrix(2,79)=tx_enc1(274);
tx_data_matrix(2,80)=tx_enc0(46);
tx_data_matrix(2,81)=tx_enc1(338);
tx_data_matrix(2,82)=tx_enc0(110);
tx_data_matrix(2,83)=tx_enc1(402);
tx_data_matrix(2,84)=tx_enc0(174);
tx_data_matrix(2,85)=tx_enc1(10);
tx_data_matrix(2,86)=tx_enc0(238);
tx_data_matrix(2,87)=tx_enc1(74);
tx_data_matrix(2,88)=tx_enc0(302);
tx_data_matrix(2,89)=tx_enc1(138);
tx_data_matrix(2,90)=tx_enc0(366);
tx_data_matrix(2,91)=tx_enc1(202);
tx_data_matrix(2,92)=tx_enc0(430);
tx_data_matrix(2,93)=tx_enc1(266);
tx_data_matrix(2,94)=tx_enc0(38);
tx_data_matrix(2,95)=tx_enc1(330);
tx_data_matrix(2,96)=tx_enc0(102);
tx_data_matrix(2,97)=tx_enc1(394);
tx_data_matrix(2,98)=tx_enc0(166);
tx_data_matrix(2,99)=tx_enc1(2);
tx_data_matrix(2,100)=tx_enc0(230);
tx_data_matrix(2,101)=tx_enc1(66);
tx_data_matrix(2,102)=tx_enc0(294);
tx_data_matrix(2,103)=tx_enc1(130);
tx_data_matrix(2,104)=tx_enc0(358);
tx_data_matrix(2,105)=tx_enc1(194);
tx_data_matrix(2,106)=tx_enc0(422);
tx_data_matrix(2,107)=tx_enc1(258);
tx_data_matrix(2,108)=tx_enc0(30);
tx_data_matrix(2,109)=tx_enc1(322);
tx_data_matrix(2,110)=tx_enc0(94);
tx_data_matrix(2,111)=tx_enc1(386);
tx_data_matrix(2,112)=tx_enc0(158);
tx_data_matrix(2,113)=tx_enc1(450);
tx_data_matrix(2,114)=tx_enc0(222);
tx_data_matrix(3,1)=tx_enc1(115);
tx_data_matrix(3,2)=tx_enc0(343);
tx_data_matrix(3,3)=tx_enc1(179);
tx_data_matrix(3,4)=tx_enc0(407);
tx_data_matrix(3,5)=tx_enc1(243);
tx_data_matrix(3,6)=tx_enc0(15);
tx_data_matrix(3,7)=tx_enc1(307);
tx_data_matrix(3,8)=tx_enc0(79);
tx_data_matrix(3,9)=tx_enc1(371);
tx_data_matrix(3,10)=tx_enc0(143);
tx_data_matrix(3,11)=tx_enc1(435);
tx_data_matrix(3,12)=tx_enc0(207);
tx_data_matrix(3,13)=tx_enc1(43);
tx_data_matrix(3,14)=tx_enc0(271);
tx_data_matrix(3,15)=tx_enc1(107);
tx_data_matrix(3,16)=tx_enc0(335);
tx_data_matrix(3,17)=tx_enc1(171);
tx_data_matrix(3,18)=tx_enc0(399);
tx_data_matrix(3,19)=tx_enc1(235);
tx_data_matrix(3,20)=tx_enc0(7);
tx_data_matrix(3,21)=tx_enc1(299);
tx_data_matrix(3,22)=tx_enc0(71);
tx_data_matrix(3,23)=tx_enc1(363);
tx_data_matrix(3,24)=tx_enc0(135);
tx_data_matrix(3,25)=tx_enc1(427);
tx_data_matrix(3,26)=tx_enc0(199);
tx_data_matrix(3,27)=tx_enc1(35);
tx_data_matrix(3,28)=tx_enc0(263);
tx_data_matrix(3,29)=tx_enc1(99);
tx_data_matrix(3,30)=tx_enc0(327);
tx_data_matrix(3,31)=tx_enc1(163);
tx_data_matrix(3,32)=tx_enc0(391);
tx_data_matrix(3,33)=tx_enc1(227);
tx_data_matrix(3,34)=tx_enc0(455);
tx_data_matrix(3,35)=tx_enc1(291);
tx_data_matrix(3,36)=tx_enc0(63);
tx_data_matrix(3,37)=tx_enc1(355);
tx_data_matrix(3,38)=tx_enc0(127);
tx_data_matrix(3,39)=tx_enc1(419);
tx_data_matrix(3,40)=tx_enc0(191);
tx_data_matrix(3,41)=tx_enc1(27);
tx_data_matrix(3,42)=tx_enc0(255);
tx_data_matrix(3,43)=tx_enc1(91);
tx_data_matrix(3,44)=tx_enc0(319);
tx_data_matrix(3,45)=tx_enc1(155);
tx_data_matrix(3,46)=tx_enc0(383);
tx_data_matrix(3,47)=tx_enc1(219);
tx_data_matrix(3,48)=tx_enc0(447);
tx_data_matrix(3,49)=tx_enc1(283);
tx_data_matrix(3,50)=tx_enc0(55);
tx_data_matrix(3,51)=tx_enc1(347);
tx_data_matrix(3,52)=tx_enc0(119);
tx_data_matrix(3,53)=tx_enc1(411);
tx_data_matrix(3,54)=tx_enc0(183);
tx_data_matrix(3,55)=tx_enc1(19);
tx_data_matrix(3,56)=tx_enc0(247);
tx_data_matrix(3,57)=tx_enc1(83);
tx_data_matrix(3,58)=tx_enc0(311);
tx_data_matrix(3,59)=tx_enc1(147);
tx_data_matrix(3,60)=tx_enc0(375);
tx_data_matrix(3,61)=tx_enc1(211);
tx_data_matrix(3,62)=tx_enc0(439);
tx_data_matrix(3,63)=tx_enc1(275);
tx_data_matrix(3,64)=tx_enc0(47);
tx_data_matrix(3,65)=tx_enc1(339);
tx_data_matrix(3,66)=tx_enc0(111);
tx_data_matrix(3,67)=tx_enc1(403);
tx_data_matrix(3,68)=tx_enc0(175);
tx_data_matrix(3,69)=tx_enc1(11);
tx_data_matrix(3,70)=tx_enc0(239);
tx_data_matrix(3,71)=tx_enc1(75);
tx_data_matrix(3,72)=tx_enc0(303);
tx_data_matrix(3,73)=tx_enc1(139);
tx_data_matrix(3,74)=tx_enc0(367);
tx_data_matrix(3,75)=tx_enc1(203);
tx_data_matrix(3,76)=tx_enc0(431);
tx_data_matrix(3,77)=tx_enc1(267);
tx_data_matrix(3,78)=tx_enc0(39);
tx_data_matrix(3,79)=tx_enc1(331);
tx_data_matrix(3,80)=tx_enc0(103);
tx_data_matrix(3,81)=tx_enc1(395);
tx_data_matrix(3,82)=tx_enc0(167);
tx_data_matrix(3,83)=tx_enc1(3);
tx_data_matrix(3,84)=tx_enc0(231);
tx_data_matrix(3,85)=tx_enc1(67);
tx_data_matrix(3,86)=tx_enc0(295);
tx_data_matrix(3,87)=tx_enc1(131);
tx_data_matrix(3,88)=tx_enc0(359);
tx_data_matrix(3,89)=tx_enc1(195);
tx_data_matrix(3,90)=tx_enc0(423);
tx_data_matrix(3,91)=tx_enc1(259);
tx_data_matrix(3,92)=tx_enc0(31);
tx_data_matrix(3,93)=tx_enc1(323);
tx_data_matrix(3,94)=tx_enc0(95);
tx_data_matrix(3,95)=tx_enc1(387);
tx_data_matrix(3,96)=tx_enc0(159);
tx_data_matrix(3,97)=tx_enc1(451);
tx_data_matrix(3,98)=tx_enc0(223);
tx_data_matrix(3,99)=tx_enc1(59);
tx_data_matrix(3,100)=tx_enc0(287);
tx_data_matrix(3,101)=tx_enc1(123);
tx_data_matrix(3,102)=tx_enc0(351);
tx_data_matrix(3,103)=tx_enc1(187);
tx_data_matrix(3,104)=tx_enc0(415);
tx_data_matrix(3,105)=tx_enc1(251);
tx_data_matrix(3,106)=tx_enc0(23);
tx_data_matrix(3,107)=tx_enc1(315);
tx_data_matrix(3,108)=tx_enc0(87);
tx_data_matrix(3,109)=tx_enc1(379);
tx_data_matrix(3,110)=tx_enc0(151);
tx_data_matrix(3,111)=tx_enc1(443);
tx_data_matrix(3,112)=tx_enc0(215);
tx_data_matrix(3,113)=tx_enc1(51);
tx_data_matrix(3,114)=tx_enc0(279);
tx_data_matrix(4,1)=tx_enc1(172);
tx_data_matrix(4,2)=tx_enc0(400);
tx_data_matrix(4,3)=tx_enc1(236);
tx_data_matrix(4,4)=tx_enc0(8);
tx_data_matrix(4,5)=tx_enc1(300);
tx_data_matrix(4,6)=tx_enc0(72);
tx_data_matrix(4,7)=tx_enc1(364);
tx_data_matrix(4,8)=tx_enc0(136);
tx_data_matrix(4,9)=tx_enc1(428);
tx_data_matrix(4,10)=tx_enc0(200);
tx_data_matrix(4,11)=tx_enc1(36);
tx_data_matrix(4,12)=tx_enc0(264);
tx_data_matrix(4,13)=tx_enc1(100);
tx_data_matrix(4,14)=tx_enc0(328);
tx_data_matrix(4,15)=tx_enc1(164);
tx_data_matrix(4,16)=tx_enc0(392);
tx_data_matrix(4,17)=tx_enc1(228);
tx_data_matrix(4,18)=tx_enc0(456);
tx_data_matrix(4,19)=tx_enc1(292);
tx_data_matrix(4,20)=tx_enc0(64);
tx_data_matrix(4,21)=tx_enc1(356);
tx_data_matrix(4,22)=tx_enc0(128);
tx_data_matrix(4,23)=tx_enc1(420);
tx_data_matrix(4,24)=tx_enc0(192);
tx_data_matrix(4,25)=tx_enc1(28);
tx_data_matrix(4,26)=tx_enc0(256);
tx_data_matrix(4,27)=tx_enc1(92);
tx_data_matrix(4,28)=tx_enc0(320);
tx_data_matrix(4,29)=tx_enc1(156);
tx_data_matrix(4,30)=tx_enc0(384);
tx_data_matrix(4,31)=tx_enc1(220);
tx_data_matrix(4,32)=tx_enc0(448);
tx_data_matrix(4,33)=tx_enc1(284);
tx_data_matrix(4,34)=tx_enc0(56);
tx_data_matrix(4,35)=tx_enc1(348);
tx_data_matrix(4,36)=tx_enc0(120);
tx_data_matrix(4,37)=tx_enc1(412);
tx_data_matrix(4,38)=tx_enc0(184);
tx_data_matrix(4,39)=tx_enc1(20);
tx_data_matrix(4,40)=tx_enc0(248);
tx_data_matrix(4,41)=tx_enc1(84);
tx_data_matrix(4,42)=tx_enc0(312);
tx_data_matrix(4,43)=tx_enc1(148);
tx_data_matrix(4,44)=tx_enc0(376);
tx_data_matrix(4,45)=tx_enc1(212);
tx_data_matrix(4,46)=tx_enc0(440);
tx_data_matrix(4,47)=tx_enc1(276);
tx_data_matrix(4,48)=tx_enc0(48);
tx_data_matrix(4,49)=tx_enc1(340);
tx_data_matrix(4,50)=tx_enc0(112);
tx_data_matrix(4,51)=tx_enc1(404);
tx_data_matrix(4,52)=tx_enc0(176);
tx_data_matrix(4,53)=tx_enc1(12);
tx_data_matrix(4,54)=tx_enc0(240);
tx_data_matrix(4,55)=tx_enc1(76);
tx_data_matrix(4,56)=tx_enc0(304);
tx_data_matrix(4,57)=tx_enc1(140);
tx_data_matrix(4,58)=tx_enc0(368);
tx_data_matrix(4,59)=tx_enc1(204);
tx_data_matrix(4,60)=tx_enc0(432);
tx_data_matrix(4,61)=tx_enc1(268);
tx_data_matrix(4,62)=tx_enc0(40);
tx_data_matrix(4,63)=tx_enc1(332);
tx_data_matrix(4,64)=tx_enc0(104);
tx_data_matrix(4,65)=tx_enc1(396);
tx_data_matrix(4,66)=tx_enc0(168);
tx_data_matrix(4,67)=tx_enc1(4);
tx_data_matrix(4,68)=tx_enc0(232);
tx_data_matrix(4,69)=tx_enc1(68);
tx_data_matrix(4,70)=tx_enc0(296);
tx_data_matrix(4,71)=tx_enc1(132);
tx_data_matrix(4,72)=tx_enc0(360);
tx_data_matrix(4,73)=tx_enc1(196);
tx_data_matrix(4,74)=tx_enc0(424);
tx_data_matrix(4,75)=tx_enc1(260);
tx_data_matrix(4,76)=tx_enc0(32);
tx_data_matrix(4,77)=tx_enc1(324);
tx_data_matrix(4,78)=tx_enc0(96);
tx_data_matrix(4,79)=tx_enc1(388);
tx_data_matrix(4,80)=tx_enc0(160);
tx_data_matrix(4,81)=tx_enc1(452);
tx_data_matrix(4,82)=tx_enc0(224);
tx_data_matrix(4,83)=tx_enc1(60);
tx_data_matrix(4,84)=tx_enc0(288);
tx_data_matrix(4,85)=tx_enc1(124);
tx_data_matrix(4,86)=tx_enc0(352);
tx_data_matrix(4,87)=tx_enc1(188);
tx_data_matrix(4,88)=tx_enc0(416);
tx_data_matrix(4,89)=tx_enc1(252);
tx_data_matrix(4,90)=tx_enc0(24);
tx_data_matrix(4,91)=tx_enc1(316);
tx_data_matrix(4,92)=tx_enc0(88);
tx_data_matrix(4,93)=tx_enc1(380);
tx_data_matrix(4,94)=tx_enc0(152);
tx_data_matrix(4,95)=tx_enc1(444);
tx_data_matrix(4,96)=tx_enc0(216);
tx_data_matrix(4,97)=tx_enc1(52);
tx_data_matrix(4,98)=tx_enc0(280);
tx_data_matrix(4,99)=tx_enc1(116);
tx_data_matrix(4,100)=tx_enc0(344);
tx_data_matrix(4,101)=tx_enc1(180);
tx_data_matrix(4,102)=tx_enc0(408);
tx_data_matrix(4,103)=tx_enc1(244);
tx_data_matrix(4,104)=tx_enc0(16);
tx_data_matrix(4,105)=tx_enc1(308);
tx_data_matrix(4,106)=tx_enc0(80);
tx_data_matrix(4,107)=tx_enc1(372);
tx_data_matrix(4,108)=tx_enc0(144);
tx_data_matrix(4,109)=tx_enc1(436);
tx_data_matrix(4,110)=tx_enc0(208);
tx_data_matrix(4,111)=tx_enc1(44);
tx_data_matrix(4,112)=tx_enc0(272);
tx_data_matrix(4,113)=tx_enc1(108);
tx_data_matrix(4,114)=tx_enc0(336);
