w0=pi/4; %transmitter carrier frequency
freqOffset=pi/10; %frequency offset (to be imposed to the signal)
phaseOffset=pi/3; %phase offset (to be imposed to the signal)
M=4; % modulation order ( cardinality of the set of symbols )
N=2000; % number of symbols to be generated
L=100; % oversampling factor, needs to be large to make PAM BW small
P=2; %power the signal will be raised to: x^P(t)
Fs=1000; %sampling frequency in Hz
nominalCarrierFrequency = w0*Fs/(2*pi); %in Hz
%% 1) Transmitter processing
%PAM generation:
indicesTx = floor(M*rand(1,N))+1; % random indices from [1, M]
alphabet = [-(M-1):2:M -1]; % symbols ..., -3, -1, 1, 3, 5, 7,...
m=alphabet(indicesTx); % obtain N random symbols
m_upsampled = zeros(1,N*L); %pre-allocate space with zeros
m_upsampled(1:L:end)=m; % symbols with L -1 zeros in - between
rollOff=0.5; %roll-off factor for raised cosine filter
Dsym=10; % group delay, at rate Rsym (input symbols rate)
p=ak_rcosine(1,L,'fir/sqrt',rollOff,Dsym); %square-root raised cosine
gdelayRC=1+(length(p)-1)/2; %group delay of this even order RC filter
s=conv(m_upsampled,p); % convolve symbols with shaping pulse
n=0:length(s)-1; %discrete-time index
carrierTx=cos(w0*n); %transmitter carrier (assume phase is 0)
s=s.*carrierTx; %upconvert to carrier frequency
%% 2) Receiver processing
carrierRx=cos((w0+freqOffset)*n+phaseOffset);%Rx carrier with offsets
r=2*s.*carrierRx; %downconvert to approximately baseband
%Estimate offsets:
[estimatedFrequencyOffset,estimatedPhaseOffset] = ...
    ak_pamCarrierRecoveryViaFFT(r,nominalCarrierFrequency,Fs);
%convert from Hz to radians:
estimatedFrequencyOffset = (2*pi*estimatedFrequencyOffset)/Fs;
%correct carrier offsets
carrOffSet=exp(-j*(estimatedFrequencyOffset*n+estimatedPhaseOffset));
r=r.*carrOffSet; %generates complex signal with offsets subtracted
r=2*real(r); %convert to real signal and take in account factor of 2
%% 3) Evaluate results
%Compare with correct values:
phaseError = phaseOffset-estimatedPhaseOffset %check error in phase
freqError = freqOffset-estimatedFrequencyOffset %check error in freq.
%Demodulate and estimate symbol error rate (SER)
r=conv(p,r); %uses matched filter (note p is symmetric and real)
startSample=2*gdelayRC; %take in account the two filtering processes
symbolsRx = r(startSample:L:startSample+L*(N-1)); %extract symbols
indicesRx=1+ak_pamdemod(symbolsRx,M); %add one to make 1,...,M
disp(['SER= ' num2str(sum(indicesRx~=indicesTx)/N)]) %error rate