w0=pi/6; %transmitter carrier frequency
freqOffset=pi/8; %frequency offset in rad (to be imposed to signal)
phaseOffset=2.45; %phase offset in rads (to be imposed to the signal)
phaseOffset=rem(phaseOffset,2*pi); %get argument from -2*pi to 2*pi
M=16; % modulation order ( cardinality of the set of symbols )
N=2000; % number of symbols to be generated
L=100; % oversampling factor, needs to be large to make BW small
P=4; %power the signal will be raised to: x^P(t)
%% 1) Transmitter processing
indicesTx = floor(M*rand(1,N))+1; % random indices from [1, M]
alphabet = ak_qamSquareConstellation(M); %QAM symbols
m=alphabet(indicesTx); % obtain N random symbols
m_upsampled = zeros(1,N*L); %pre-allocate space with zeros
m_upsampled(1:L:end)=m; % symbols with L -1 zeros in - between
rollOff=0.5; %roll-off factor for raised cosine filter
Dsym=10% group delay, at rate Rsym (input symbols rate)
p=ak_rcosine(1,L,'fir/sqrt',rollOff,Dsym); %square-root raised cosine
gdelayRC=1+(length(p)-1)/2; %group delay of this even order RC filter
s=conv(m_upsampled,p); % convolve symbols with shaping pulse
BWq=2*pi/L*(1+rollOff); %QAM bandwidth
n=0:length(s)-1; %discrete-time index
carrierTx=cos(w0*n); %transmitter carrier (assume phase is 0)
s=s.*carrierTx; %upconvert to carrier frequency
%% 2) Receiver processing
carrierRxArgument=(w0+freqOffset)*n+phaseOffset;%carrier with offsets
r=2*s.*exp(1j*carrierRxArgument); %downconvert to approximately baseband
%2.1) Carrier recovery
ntaps=101; %number of filter taps, make it an odd number
freqOffsetRx = freqOffset+0.05; %Rx has to guess the freq. offset
w1=(P*freqOffsetRx-BWq)/pi; %cutoff frequencies for filter that ...
w2=(P*freqOffsetRx +BWq)/pi; %should recover sinusoid at P*freqOffset
ff=[0 w1-0.1 w1 w2 w2+0.1 1]; %frequencies for carrier recov. filter
%h=fir1(ntaps,[max(0,w1-0.1) min(1,w2+0.1)]);
h=firpm(ntaps,ff,[0 0 1 1 0 0]); %design filter for carrier recovery
%r_carrierRecovery=filter(1,1,r.^P); %filter the r^P signal (not r)
r_carrierRecovery=filter(h,1,r.^P); %filter the r^P signal (not r)
R=fft(r_carrierRecovery); Nfft=length(R); %calculate FFT
[maxPeak,indexMaxPeak]=max(abs(R(1:Nfft/2))) %find the strongest peak
estimatedFrequencyOffset=(2*pi/Nfft*(indexMaxPeak-1))/P %in rad
angle(R(indexMaxPeak)) %phase of r^P signal
%Compensate phase added by the filter at frequency of interest:
filterPhases=angle(freqz(h,1,[0 P*estimatedFrequencyOffset pi]));
estimatedPhaseOffset=(angle(R(indexMaxPeak))-filterPhases(2))/P;%est.
bestAmbiguousValue=NaN;
minError=Inf;
for ambiguousValue=-8:8 %allow range -2*pi to 2*pi of pi/4 multiples
    %-pi/4 for offset [0,0.15],  3*pi/4 for offset [pi/2+0.2 pi+0.5]
    temp = estimatedPhaseOffset+ambiguousValue*pi/4;
    %Compare with correct ("golden truth") values:
    phaseError = phaseOffset-temp; %check error in phase
    if abs(phaseError) < minError
        minError=abs(phaseError);
        bestAmbiguousValue=ambiguousValue;
    end
end
bestAmbiguousValue=0;
estimatedPhaseOffset = estimatedPhaseOffset+bestAmbiguousValue*pi/4
phaseError = phaseOffset-estimatedPhaseOffset %check error in phase
freqError = freqOffset-estimatedFrequencyOffset %check error in freq.
%2.2) Correct carrier offsets
carrOffSet=exp(-j*(estimatedFrequencyOffset*n+estimatedPhaseOffset));
r=r.*carrOffSet; %generates complex signal with offsets subtracted
%r=2*real(r); %convert to real signal and take in account factor of 2
%2.3) Demodulate
r=conv(p,r); %uses matched filter (note p is symmetric and real)
startSample=2*gdelayRC; %take in account the two filtering processes
symbolsRx = r(startSample:L:startSample+L*(N-1)); %extract symbols
indicesRx=1+ak_qamdemod(symbolsRx,M); %add one to make 1,...,M
disp(['SER= ' num2str(sum(indicesRx~=indicesTx)/N)]) %error rate