%% Example of QAM demodulation
%generate QAM signal centered at Fs/4
M=16; %number of symbols
constellat=ak_qamSquareConstellation(M); %QAM const.
S=1000; %number of symbols
ind=floor(M*rand(1,S)); %indices
qamSymbols=constellat(ind+1); %sequence of random symbols
L=8; %oversampling factor
x=zeros(1,S*L); %pre-allocate space
x(1:L:end)=qamSymbols; %complete upsampling operation
p=ak_rcosine(1,L,'fir/normal',0.5,10); %raised cosine r=0.5
yce=conv(p,x); %complex env.: convolution by shaping pulse
%modulate by carrier at pi/2 rad that corresponds to Fs/4
n=0:length(yce)-1; %"time" axis
z=real(yce .* exp(j*pi/2*n)); %transmitted signal
r = z;  %ideal channel: no noise, unlimited band (z has been defined)
%now run the demodulation:
n=0:length(r)-1;
ri = r .* (2*cos(pi/2*n)); %in-phase component
rq = -r .* (2*sin(pi/2*n)); %quadrature component (note -)
%make a FIR with the same order of the shaping filter
%and use a cutoff frequency of pi/2 rad
b=fir1(length(p)-1,0.5);
ri = conv(b,ri); %filter the two components to eliminate
rq = conv(b,rq); %the terms at twice the carrier frequency
ybb=ri + j * rq; %recompose complex envelope at baseband
%take out the transient due to the filters, otherwise it
%shows spurious symbol at (0,0) due to filter's transients
ybb(1:floor(length(p)/2)+floor(length(b)/2))=[];
firstSample = 1; %first sample to start getting symbols
ys=ybb(firstSample:L:L*S); %sample S symbols, baud rate
symbolIndicesRx=ak_qamdemod(ys,M); %QAM demodulation
SER=ak_calculateSymbolErrorRate(symbolIndicesRx,ind)
