function [frequencyOffset,phaseOffset,h_filter,resolutionHz] = ...
    ak_pamCarrierRecoveryViaFFT(r,minFreqOffset,maxFreqOffset,Fs, ...
    desiredResolutionHz)
% function [angularFreqOffset,phaseOffset,h_filter,resolutionHz]= ...
%    ak_pamCarrierRecoveryViaFFT(r,nominalCarrierFrequency,Fs)
%Inputs: r => received signal after frequency downconversion
%        nominalCarrierFrequency => ideal carrier frequency (Hz)
%        Fs => sampling frequency in Hz
%Outputs: frequencyOffset => estimated frequency offset in Hz
%         phaseOffset => estimated phase offset in rad
%         h_filter => impulse response of adopted bandpass FIR
debugOn=1; %enable to debug
freqNormalization=1e3; %kHz for plotting purposes only
P=2; %power the signal will be raised to: x^P(t)
ntaps=101; %number of filter taps, make it an odd number
fc_lowpass = maxFreqOffset/(Fs/2);
if fc_lowpass < 0.005 %avoid too small cutoff frequency
    fc_lowpass = 0.005;
end
h_filter=fir1(ntaps,fc_lowpass); %design lowpass filter
r_carrierRecovery=filter(h_filter,1,r.^P);%filter r^P signal (not r)
if 0 %decimate to decrease cost
    decimationFactor=floor(1/fc_lowpass);
    r_carrierRecovery(1:decimationFactor:end);
    Fs=Fs/decimationFactor;
end
%Will use at least desired resolution:
Nfft = max(Fs/desiredResolutionHz,length(r_carrierRecovery));
%Nfft = length(r_carrierRecovery);
if rem(Nfft,2) == 1
    Nfft=Nfft+1;
end
%We have to estimate the peak corresponding to DC:
if 0 %first option is a simple strategy
    [S,w]=pwelch(r_carrierRecovery); %later, we should control PSD resolution
    % search end of PSD peak associated to DC
    indexOfInterest=1; %w(indexOfInterest) will inform end DC peak ends
    while S(indexOfInterest+1) < S(indexOfInterest)
        indexOfInterest=indexOfInterest+1;
    end
    if debugOn==1
        figure(2), clf; plot(Fs*w/(2*pi)/freqNormalization,log10(S)), title('PSD')
        hold on, plot(Fs*w(indexOfInterest)/(2*pi)/freqNormalization,log10(S(indexOfInterest)),'rx')
    end
    %map index of PSD to index of FFT:
    minIndexOfInterestInFFT = floor(w(indexOfInterest)/((2*pi)/Nfft));
    if minIndexOfInterestInFFT == 0;
        minIndexOfInterestInFFT = 1; %make sure at least DC is eliminated
    end
elseif 1
    minIndexOfInterestInFFT = ceil(2*minFreqOffset/(Fs/Nfft));
    maxIndexOfInterestInFFT = ceil(5*maxFreqOffset/(Fs/Nfft));
else %use findpeaks
    [peaks,locs] = findpeaks(r_carrierRecovery);
    plot(locs,peaks,'x')
    error('did not finish')
end
if 0 %tried goertzel but did not work
    r_carrierRecovery=[r_carrierRecovery zeros(1,Nfft-length(r_carrierRecovery))];
    R=goertzel(r_carrierRecovery, ...
        [minIndexOfInterestInFFT:maxIndexOfInterestInFFT]);
end
R=fft(r_carrierRecovery,Nfft); %Nfft=length(R); %calculate FFT
R(1:minIndexOfInterestInFFT)=0; %eliminate peak relative to DC
R(Nfft/2:end)=[]; %eliminate negative frequencies
R(maxIndexOfInterestInFFT:end)=[]; %eliminate other peaks at right
[maxPeak,indexMaxPeak]=max(abs(R)); %find strongest peak
resolutionHz = Fs/Nfft; %FFT analysis resolution
faxis=(0:length(R)-1)*resolutionHz/freqNormalization;
if debugOn==1
    figure(1), clf; plot(faxis,log10(abs(R))), title('FFT')
    hold on, plot(faxis(indexMaxPeak),log10(abs(R(indexMaxPeak))),'rx'),
    xlabel([' f (\times 10^' num2str(log10(freqNormalization)) ' Hz)'])
end
angularFreqOffset=(2*pi/Nfft*(indexMaxPeak-1))/P; %in rad
%Compensate phase added by the filter at frequency of interest:
filterPhases=angle(freqz(h_filter,1,[0 P*angularFreqOffset pi]));
%we use 3 frequencies above because freqz requires an array
phaseOffset=(angle(R(indexMaxPeak))-filterPhases(2))/P; %phase estim.
%phaseOffset=phaseOffset+pi; %"Empirical". Should check this
frequencyOffset = angularFreqOffset*Fs/(2*pi); %convert rad to Hz
%the assumption was that frequencyOffset < nominalCarrierFrequency/2:
if frequencyOffset > maxFreqOffset/2
    disp('Warning: frequencyOffset > nominalCarrierFrequency/2');
end