%Script cioffi_example411.m
%Table 4.1 - Example 4.1.1 in Cioffi notes
%Adopted convention:
%k => time index
%n => frequency index

h=[0.9 1] % H(z) = 0.9z + 1, non-causal channel
N = 8;
sigma2 = 0.181; %No/2 PSD level
gapdB = 4.4
gap = 10^(gapdB / 10)  %db = 10 log10 (linear)

% H(z) = 0.9z + 1 => H(n) = 1 + 0.9 exp (j w_n), where w_n=(2 pi n)/N
% H(n) = 1 + 0.9 exp (j 2 pi n / 8)
n = 0:N-1;
if 1
    %using the expression itself
    H = 1 + 0.9 * exp (j*2*pi*n./8);
    mag = abs(H)
    phase = angle(H)/pi*180
else
    %using FFT (normalized by N). In this case, one has to "tell" that
    %h starts at k=-1 (because the FFT assumes k=0) and add a linear phase
    linear_phase = exp(j*2*pi*(1)*n/8);
    H = fft(h,N) .* linear_phase; %add linear phase
    mag = abs(H)
    phase = angle(H)/pi*180
end

%In multicarrier, the dimension of each subchannel is called subdimension.
%note that the author seems to say the same energy per dimension, and
%that would lead to the QAMs with half the energy per subdimension of the
%PAM subchannel. Then the SNR would be lower in the QAM signals than the
%numbers in the Table 4.1 because the noise is twice in the QAMs. Because
%of that, we are assuming the author wanted the same energy per
%subdimension. In this case, everything matches, but the transmit power is
%not 1 Watt anymore.
energy_per_subchannel = [8 16 16 16 0 16 16 16]/7
noise_per_subchannel = sigma2*[1 2 2 2 2 2 2 2];
SNR = (energy_per_subchannel .* mag.^2) ./ noise_per_subchannel
SNR_db = 10 * log10(SNR)

%It seems that Cioffi did not take the power in negative frequencies.
%To check if Cioffi is mistaken when says the transmit power is 1 Watt:
[A, Ai]=ak_fftmtx(8,1); %normalized DFT is used,Parseval does hold
%Find "DC" values that have the given power
if 1
    %same energy per subdimension => Power is NOT 1 Watt
    X=sqrt(energy_per_subchannel);
else
    %same energy per dimension => Power = 1 Watt
    X=sqrt([8 8 8 8 0 8 8 8]/7);
end
x=Ai*X'; %transform to time-domain
%check the power (and see that Parseval applies):
powerTime = sum(abs(x).^2)/8
powerFreq = sum(abs(X).^2)/8

bn = 0.5*log2(1 + SNR/gap)
%rounding
bn2 = [1.6 1.5 1.2 0.5 0 0.5 1.2 1.5];
bn2 = [1.6 2*[1.5 1.2 0.5] 0]; %reorganize vector
%note that the bits in the negative frequency subchannels do not count
average_b_per_subdimension = sum(bn2(1:5)) / 8

M = 2 .^ bn2
argQ = [sqrt( (3./(M(1)^2 - 1)) .* SNR(1)) sqrt( (3./(M(2:4) - 1)) .* SNR(2:4))]
argQ_db = 20 * log10(argQ)

%calculate the probability of subsymbol error (per subchannel)
%for PAM
Pe = 2*(1-1/M(1))*qfunc(sqrt( (3./(M(1)^2 - 1)) .* SNR(1)))

Pe = 2*(1-1./M(2:4)).*qfunc(sqrt( (3./(M(2:4) - 1)) .* SNR(2:4)))
