function [y,w]=dbmagfft(x,N,isnormalized,samplingFrequency,quiet)
% function [y,w]=dbmagfft(x,N,isnormalized,samplingFrequency)
%
%calculates the dB magnitude spectrum of input signal x
%using an N-point FFT. If quiet is not 1 and length(x) > N, it gives a warning.
%If isnormalized = 1, divides the FFT result by FFT length
%samplingFrequency in Hz, default = 1 Hz
%Output is y in dB and w in radians per second
%Aldebaro - July 2007

if nargin < 5
    quiet = 1;
end

if nargin < 4
    samplingFrequency = 1;
end

if nargin < 3
   isnormalized = 0;
end

if nargin == 1 
   N = length(x);
end

if (quiet == 1 & length(x) > N)
    warning(['length(x) = ' num2str(length(x)) ' > N. Will use N = ' num2str(N)])
end

delta=(2*pi)/N;
w=samplingFrequency * (-pi:delta:pi-delta);

if isnormalized == 1
   y=20*log10(fftshift(abs(fft(x,N))/N));
else   
   y=20*log10(fftshift(abs(fft(x,N))));
end

if nargout == 0
    if samplingFrequency == 1
        plot(w,y);
        xlabel('Frequency (radians)');
    else
        plot(w/(2*pi),y);
        xlabel('Frequency (Hz)');
    end
    ylabel('dB Magnitude');
    grid
end