%Prova 4 - questao 2
clear all, close all
showPlots = 1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Problem-specific information
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if 1
    N=6 %number of subchannels
    h=10^(-6)*[1 1 0 0 1]; %channel
    L=4 %guard interval    
else
    %example 4.5.1 in Cioffi, page 338
    h=[0.9 1] %channel
    L=1 %guard interval
    N=8 %number of subchannels
end

margin_dB = 3 %margin in dB
margin = 10^(0.1*margin_dB) %convert to linear scale

%The channel is real (baseband), so we cannot use QAM, only PAM
Pe = 1e-3; %target error probability
gap = 1/3 * qfuncinv(Pe/2)^2 %gap calculation for uncoded PAM
gap_dB = 10 * log10(gap) %convert linear to dB

noisePSD_dBm = -110;
N0d2 = 1e-3 * 10^(noisePSD_dBm/10) %convert from dBm to Watts

totalPower_dBm = 40;
totalPower = 1e-3 * 10^(totalPower_dBm/10) %convert from dBm to Watts

%find symbol rate in Hz (or bauds) from sampling frequency
fs = 100e3; %in Hz
Ts = 1/fs
T = (N+L)*Ts
%item a) 
bauds = 1/T

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Design the SVD-based system: find the modulator e demodulator matrices
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Eq. (4.181), page 336, from Cioffi:
%the channel matrix has dimension N x (N+L) and has the impulse response
%filled with N-1 zeros on its rows
numZeros = N-1
h_withzeros = [h zeros(1,numZeros)]
P = transp(circulant(h_withzeros));  %creates a (N+L) x (N+L) matrix
P = P(1:N,:)  %want to keep only the first N rows

%    [U,S,V] = SVD(X) produces a diagonal matrix S, of the same 
%    dimension as X and with nonnegative diagonal elements in
%    decreasing order, and unitary matrices U and V so that X = U*S*V'.
% note: http://mathworld.wolfram.com/UnitaryMatrix.html
[F,S,Mhermitian] = svd(P);
lambdas = diag(S);
M=Mhermitian';

%check SVD decomposition for numerical errors
P2 = F*S*M;
error = max(abs(P(:)-P2(:)))

%check if the matrices can "partition" the channel
%because the matrices are unitary F*F'=I and M*M'=I
% P=F*S*M => F'*P*M' = S
S2 = F'*P*M';
error = max(abs(S(:)-S2(:)))

%get the magnitude (gains) of each subchannel
g = lambdas.^2;

%now do waterfilling: all subchannels are submitted to the same noise
[txPower,waterlevel,SNR]= ...
    simplewaterfill(g,N0d2,gap,totalPower);

if showPlots == 1
    %plot waterfilling figure in linear scale
    g = transp(g);
    noise = N0d2 * ones(size(g));
    A=[gap * (noise./g);
        txPower];
    bar(A','stacked')
    xlabel('Tones (k)')
    ylabel('Stacked: inverse SNR (\Gamma\sigma/g) and Tx power')
    hold on
    plot(1:length(txPower),waterlevel*ones(size(txPower)),'-X','markersize',16);
    hold off
    pause
end

%sanity check
if (sum(txPower) - totalPower > 1e-15) 
    error('sum(txPower) differs from totalPower!')
end

SNRdB = 10*log10(SNR)

bitsPerDimension=0.5*log2(1 + SNR/(gap*margin))  %only PAM

bits = floor(bitsPerDimension)

rate = bauds*sum(bits)
    